@@ -494,7 +494,7 @@ def eaSimple(population, toolbox, cxpb, mutpb, ngen, stats=None,
         for ind, fit, in zip(invalid_ind, fitnesses):
             ind.fitness.values = fit[0],
             ind.expr = fit[1]
-            ind.dim = fit[2]
+            ind.y_dim = fit[2]
             ind.withdim = fit[3]
         random.setstate(rst)
 
@@ -519,13 +519,13 @@ def eaSimple(population, toolbox, cxpb, mutpb, ngen, stats=None,
                                                    "score": i.fitness.values[0],
                                                    "expr": str(subp(i.expr)),
                                                    "with_dim": 1 if i.withdim else 0,
-                                                   "dim_is_target_dim": 1 if i.dim in target_dim else 0,
+                                                   "dim_is_target_dim": 1 if i.y_dim in target_dim else 0,
                                                    "gen_dim": "{}{}".format(gen, 1 if i.withdim else 0),
                                                    "gen_target_dim": "{}{}".format(gen,
-                                                                                   1 if i.dim in target_dim else 0),
+                                                                                   1 if i.y_dim in target_dim else 0),
                                                    "socre_dim": i.fitness.values[0] if i.withdim else 0,
                                                    "socre_target_dim": i.fitness.values[
-                                                       0] if i.dim in target_dim else 0,
+                                                       0] if i.y_dim in target_dim else 0,
                                                    } for n, i in enumerate(population) if i is not None}
             data_all.update(data)
         random.setstate(rst)
@@ -543,7 +543,7 @@ def eaSimple(population, toolbox, cxpb, mutpb, ngen, stats=None,
         rst = random.getstate()
         """Dynamic output"""
 
-        record = stats.compile(population) if stats else {}
+        record = stats.compile_(population) if stats else {}
         logbook.record(gen=gen, pop=len(population), **record)
 
         if verbose:
@@ -645,16 +645,16 @@ def selKbestDim(pop, K_best=10, dim_type=None, fuzzy=False):
     if dim_type is None:
         add_ind = [ind for ind in chosen if ind.withdim == 1]
     elif dim_type is 'integer':
-        add_ind = [ind for ind in chosen if ind.dim.isinteger]
+        add_ind = [ind for ind in chosen if ind.y_dim.isinteger]
     elif dim_type is 'ignore':
         add_ind = chosen
     elif isinstance(dim_type, list):
-        add_ind = [ind for ind in chosen if ind.dim in dim_type]
+        add_ind = [ind for ind in chosen if ind.y_dim in dim_type]
     elif isinstance(dim_type, Dim):
         if fuzzy:
-            add_ind = [ind for ind in chosen if ind.dim.is_same_base(dim_type)]
+            add_ind = [ind for ind in chosen if ind.y_dim.is_same_base(dim_type)]
         else:
-            add_ind = [ind for ind in chosen if ind.dim == dim_type]
+            add_ind = [ind for ind in chosen if ind.y_dim == dim_type]
     else:
         raise TypeError("dim_type should be None, 'integer', special Dim or list of Dim")
     if K_best is None:
